#ifndef		__MSR600U_DLL_H__
#define		__MSR600U_DLL_H__

#include "hidapi.h"
#include <stdlib.h>
#include <stdio.h>
#include <string.h>
#include <unistd.h>
#include <malloc.h>



//===constant============
#define  CMD_OK				0
#define  CMD_WRONG_PARAM	1
#define	 CMD_TIME_OUT		2
#define  CMD_FAILED			3

#define  PID		0x572B
#define  VID		0x0483



typedef unsigned char       BYTE;
typedef hid_device*			HANDLE;	

//#include "common.h"

/*************************************************************************************
函数名：	MSR600_Open
功能描述：	打开MSR600设备
参数列表：	[in]	nProductId	usb设备的product id
			[in]	nVendorId	usb设备的vendor id
返回值：	成功：	返回打开的设备的句柄
			失败：	INVALID_HANDLE_VALUE
*************************************************************************************/
HANDLE MSR600_Open(
	int nProductId, 
	int nVendorId);



/*************************************************************************************
函数名：	MSR600_Close
功能描述：	关闭MSR600设备
参数列表：	[in]devHandle	设备的句柄
返回值：	成功：	CMD_OK；
			失败：	其他返回
*************************************************************************************/
int MSR600_Close(
	HANDLE devHandle
	);



/*************************************************************************************
函数名：	MSR600_FwVer
功能描述：	获取MSR600设备的fireware版本信息
参数列表：	[in]	devHandle	设备的句柄		
			[out]	pVersionInfo	保存版本的信息
			[in]	nWaitTimeOut	命令响应的等待超时
返回值：	成功：	CMD_OK；
			失败：	其他返回
*************************************************************************************/
int	 MSR600_FwVer(
	HANDLE devHandle, 
	char *pVersionInfo, 
	int nWaitTimeOut=2500);


/*************************************************************************************
函数名：	MSR600_DecodeAutoTransData
功能描述：	获取并解析MRS600自动上传的数据
参数列表：	[in]	devHandle		设备的句柄			
			[out]	pD_Type			磁卡的数据格式，详情参考协议
			[out]	pEncrypMode	磁卡的加密，详情参考协议
			[out]	pDeviceId			设备信息，详情参考协议
			[out]	pT1_Status			‘Y’读卡成功，其他值读卡失败
			[out]	pT1_Len			一轨道数据长度
			[out]	pT1_Data			一轨道数据
			[out]	pT2_Status		‘Y’读卡成功，其他值读卡失败
			[out]	pT2_Len			二轨道数据长度
			[out]	pT2_Data			二轨道数据
			[out]	pT3_Status		‘Y’读卡成功，其他值读卡失败
			[out]	pT3_Len			三轨道数据长度
			[out]	pT3_Data			三轨道数据
			[out]	piBtnStatus		ibtn的状态
			[out]	pCardNo			ibtn的卡号
			[out]	pCardNoLen		ibtn卡号的长度
			[in]	nWaitTimeOut	命令响应的等待超时
返回值：	成功：	CMD_OK；
			失败：	其他返回
*************************************************************************************/
int MSR600_DecodeAutoTransData(
	HANDLE devHandle,
	BYTE *pD_Type,
	BYTE *pEncrypMode,
	int	 *pDeviceId,
	BYTE *pT1_Status, BYTE *pT1_Len, BYTE *pT1_Data,
	BYTE *pT2_Status, BYTE *pT2_Len, BYTE *pT2_Data,
	BYTE *pT3_Status, BYTE *pT3_Len, BYTE *pT3_Data,
	BYTE *piBtnStatus, BYTE *pCardNo, BYTE *pCardNoLen,
	int nWaitTimeOut = 1500);


/*************************************************************************************
函数名：	 	MSR600_MagMode
功能描述：	设置MSR600设备磁卡读卡器的数据传输模式
参数列表：	[in]devHandle		设备的句柄
			[in]transProtocol	0=HID Keyboard 模拟键盘; 1=HID Custom （在此模式下读卡数据需要计算机软件处理方可显示）
			[in]nWaitTimeOut	命令响应的等待超时
返回值：		成功：	CMD_OK；
			失败：	其他返回
*************************************************************************************/
int MSR600_MagMode(
	HANDLE devHandle,
	BYTE transProtocol = 1,
	int nWaitTimeOut = 2500
);


/*************************************************************************************
函数名：	 	MSR600_MagDataFormat
功能描述：	设置MSR600设备磁卡读卡器的数据格式
参数列表：	[in]	devHandle		设备的句柄
					[in]	t1SS					一轨道起始符号
					[in]	t1ES					一轨道结束符号
					[in]	t2SS					二轨道起始符号
					[in]	t2ES					二轨道结束符号
					[in]	t3SS					三轨道起始符号
					[in]	t3ES					三轨道结束符号
					[in]	outputT1			一轨道是否输出：true=输出, false=不输出
					[in]	outputT2			二轨道是否输出：true=输出, false=不输出
					[in]	outputT3			三轨道是否输出：true=输出, false=不输出
					[in]	endChar			整包数据输出完毕后，包尾结束符号，Enter（0X58），Tab (0X2B) ，没有（0），其他数据用户自行输入（ASCII）
					[in]	nWaitTimeOut	命令响应的等待超时
返回值：		成功：	CMD_OK；
					失败：	其他返回
*************************************************************************************/
int MSR600_MagDataFormat(
	HANDLE devHandle,
	BYTE t1SS = '%', BYTE t1ES = '?',
	BYTE t2SS = ';', BYTE t2ES = '?',
	BYTE t3SS = '+', BYTE t3ES = '?',
	bool outputT1 = true, 
	bool outputT2 = true,
	bool outputT3 = true,
	BYTE endChar = 0,
	int nWaitTimeOut = 2500
);

/*************************************************************************************
函数名：	 	MSR600_MagReset
功能描述：	MSR600设备磁卡读卡器恢复默认设置
参数列表：	[in]	devHandle		设备的句柄
					[in]	nWaitTimeOut	命令响应的等待超时
返回值：		成功：	CMD_OK；
					失败：	其他返回
*************************************************************************************/
int MSR600_MagReset(
	HANDLE devHandle,
	int nWaitTimeOut = 2500
);


/*************************************************************************************
函数名：	 	MSR600_MagGetOption
功能描述：	获取MSR600设备磁卡读卡器的设置信息
参数列表：	[in]	devHandle			设备的句柄
			[out]	pTransProtocol		0=HID Keyboard 模拟键盘; 1=HID Custom （在此模式下读卡数据需要计算机软件处理方可显示）
			[out]	pT1SS					一轨道起始符号
			[out]	pT1ES					一轨道结束符号
			[out]	pT2SS					二轨道起始符号
			[out]	pT2ES					二轨道结束符号
			[out]	pT3SS					三轨道起始符号
			[out]	pT3ES					三轨道结束符号
			[out]	pOutputT1			一轨道是否输出：1=输出, 0=不输出
			[out]	pOutputT2			二轨道是否输出：1=输出, 0=不输出
			[out]	pOutputT3			三轨道是否输出：1=输出, 0=不输出
			[out]	pEndChar				整包数据输出完毕后，包尾结束符号，Enter（0X58），Tab (0X2B) ，没有（0），其他数据用户自行输入（ASCII）
			[out]	nWaitTimeOut		命令响应的等待超时
返回值：	成功：	CMD_OK；
			失败：	其他返回
*************************************************************************************/
int MSR600_MagGetOption(
	HANDLE devHandle,
	BYTE* pTransProtocol,
	BYTE* pT1SS, BYTE *pT1ES,
	BYTE* pT2SS, BYTE *pT2ES,
	BYTE* pT3SS, BYTE *pT3ES,
	BYTE* pOutputT1,
	BYTE* pOutputT2,
	BYTE* pOutputT3,
	BYTE* pEndChar,
	int nWaitTimeOut = 2500
);

/*************************************************************************************
函数名：	MSR600_iBtnMode
功能描述：	设置MSR600设备iBtn的数据模式
参数列表：	[in]	devHandle		设备的句柄
			[in]	transProtocol	0,  keyboard 模式，1，hid custom模式
			[in]	dataFormat,		0，发送的数据为hex模式，1，10位十进制模式
			[in]	nWaitTimeOut	命令响应的等待超时
返回值：	成功：	CMD_OK；
			失败：	其他返回
*************************************************************************************/
int MSR600_iBtnMode(
	HANDLE devHandle,
	BYTE transProtocol=1,
	BYTE dataFormat=0,
	int nWaitTimeOut = 2500
);


/*************************************************************************************
函数名：	MSR600_iBtnEndChar
功能描述：	MSR600设备iBtn设置数据包为结束符
参数列表：	[in]	devHandle		设备的句柄					
			[in]	endChar			包尾结束符号，Enter（0X58），Tab (0X2B) ，没有（0），其他数据用户自行输入（ASCII）
			[in]	nWaitTimeOut	命令响应的等待超时
返回值：	成功：	CMD_OK；
失败：		其他返回
*************************************************************************************/
int MSR600_iBtnEndChar(
	HANDLE devHandle,
	BYTE endChar=0,
	int nWaitTimeOut = 2500
);

/*************************************************************************************
函数名：	MSR600_iBtnWithDraw
功能描述：	MSR600设备iBtn设置withDraw数据
参数列表：	[in]	devHandle		设备的句柄
			[in]	pDrawData		withDraw字符串
			[in]	drawLen			drawLen字符串的长度 (0到15)
			[in]	nWaitTimeOut	命令响应的等待超时
返回值：	成功：	CMD_OK；
			失败：	其他返回
*************************************************************************************/
int MSR600_iBtnWithDraw(
	HANDLE devHandle,
	BYTE *pDrawData,
	int   drawLen,
	int nWaitTimeOut = 2500
);

/*************************************************************************************
函数名：	 	MSR600_iBtnPrefixSuffix
功能描述：	MSR600设备iBtn设置前后缀数据
参数列表：	[in]	devHandle		设备的句柄
			[in]	pPreFix				前缀数据
			[in]	preFixLen			前缀数据长度 (0到15)
			[in]	pSurfix				后缀数据
			[in]	surFixLen			后缀数据长度 (0到15)
			[in]	nWaitTimeOut	命令响应的等待超时
返回值：	成功：	CMD_OK；
			失败：	其他返回
*************************************************************************************/
int MSR600_iBtnPrefixSuffix(
	HANDLE devHandle,
	BYTE* pPrefix, int preFixLen,
	BYTE* pSurfix, int surFixLen,
	int nWaitTimeOut = 2500
);


/*************************************************************************************
函数名：	 	MSR600_iBtnReset
功能描述：	MSR600设备iBtn恢复默认设置
参数列表：	[in]	devHandle		设备的句柄
			[in]	nWaitTimeOut	命令响应的等待超时
返回值：	成功：	CMD_OK；
			失败：	其他返回
*************************************************************************************/
int MSR600_iBtnReset(
	HANDLE devHandle,
	int nWaitTimeOut = 2500);


/*************************************************************************************
函数名：	 	MSR600_iBtnGetOption
功能描述：	MSR600设备iBtn获取参数设置
参数列表：	[in]	devHandle			设备的句柄
					[out]	pTransProtocol		0,  keyboard 模式，1，hid custom模式
					[out]	pDataFormat		0，发送的数据为hex模式，1，10位十进制模式
					[out]	pEndChar				数据包尾，结束字符，一个字节
					[out]	pWithDrawlLen		withDraw数据的长度
					[out]	pWithDraw			withDraw数据
					[out]	pPreFixLen			前缀数据长度
					[out]	pSubffixLen			后缀数据
					[out]	pPreFix					前缀数据
					[out] pSuffix					后缀数据
					[in]	nWaitTimeOut		命令响应的等待超时
返回值：		成功：	CMD_OK；
					失败：	其他返回
*************************************************************************************/
int MSR600_iBtnGetOption(
	HANDLE devHandle,
	BYTE *pTransProtocol,
	BYTE *pDataFormat,
	BYTE *pEndChar,
	BYTE *pWithDrawLen,
	BYTE *pWithDraw,
	BYTE *pPreFixLen,
	BYTE *pSubffixLen,
	BYTE *pPreFix,
	BYTE *pSuffix,
	int nWaitTimeOut = 2500
);




#endif // ! __MSR600U_DLL_H__

